Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/twbs/mq4-hover-shim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorChris Rebert <github@rebertia.com>2015-01-05 11:38:14 +0300
committerChris Rebert <github@rebertia.com>2015-01-05 11:38:14 +0300
commitead19f2517d55627186fb766dcf40935eae8434c (patch)
tree877445f37c50e72f9a215db68d8bf3567c995654 /src
parent4637bb9c87a4c0556ce83f1c0f953c7a4643f5f9 (diff)
Android 2.3 doesn't support matchMedia
Diffstat (limited to 'src')
-rw-r--r--src/browser/mq4-hover-hover-shim.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/browser/mq4-hover-hover-shim.js b/src/browser/mq4-hover-hover-shim.js
index 5477d13..654141d 100644
--- a/src/browser/mq4-hover-hover-shim.js
+++ b/src/browser/mq4-hover-hover-shim.js
@@ -10,9 +10,9 @@
*/
export function supportsTrueHover() {
if (!window.matchMedia) {
// Opera Mini, IE<=9, ancient, or obscure; per http://caniuse.com/#feat=matchmedia
// Opera Mini and IE Mobile don't support true hovering, so they're what we'll check for.
// Other browsers are either:
// (a) obscure
// (b) touch-based but old enough not to attempt to emulate hovering
@@ -22,7 +22,7 @@ export function supportsTrueHover() {
// IE Mobile <9 seems to always have "Windows CE", "Windows Phone", or "IEMobile" in its UA string.
// IE Mobile 9 in desktop view doesn't include "IEMobile" or "Windows Phone" in the UA string,
// but it instead includes "XBLWP7" and/or "ZuneWP7".
- return !/Opera Mini|IEMobile|Windows (Phone|CE)|(XBL|Zune)WP7/.test(navigator.userAgent);
+ return !/Opera Mini|Android|IEMobile|Windows (Phone|CE)|(XBL|Zune)WP7/.test(navigator.userAgent);
}
// CSSWG Media Queries Level 4 draft
@@ -10,9 +10,9 @@
export function supportsTrueHover() {
if (!window.matchMedia) {
- // Opera Mini, IE<=9, ancient, or obscure; per http://caniuse.com/#feat=matchmedia
+ // Opera Mini, IE<=9, Android<=2.3, ancient, or obscure; per http://caniuse.com/#feat=matchmedia
- // Opera Mini and IE Mobile don't support true hovering, so they're what we'll check for.
+ // Opera Mini, Android, and IE Mobile don't support true hovering, so they're what we'll check for.
// Other browsers are either:
// (a) obscure